; Camera Shutter Speed Test Program
;
; In reality this might be considered a 'concept program'
; as there are so many ways it could be adapted or improved.
; Likewise the timing parts of the program are not exact in
; their values as they are more than adequate for their
; proposed use. As I am intending to eventually make
; substantial alterations to both hardware and software, there
; seemed little point in spending many hours to simply
; calculate exact timing values to never use them!
;
; Note that there will probably be few (if any) changes
; needed if an alternative D - A converter is used.
;
; Although a separate DL1414 display is used on the board,
; there is no real reason why one of those on the Sitcom
; itself cannot be used if they are already fitted.
;
; Additional shutter speed timings can be easily added to this
; code, but one should be aware that (as in the case of my
; prototype) the performance of the existing hardware
; design may limit any higher frequency measurements.
;
;
;-----------------------------------

        .CR     8080
        .CP     1,9600,N,8,1    Change com port if necessary
        .TF     COM1:,INT       Change com port if necessary

;-----------------------------------
;
PORTA   .EQ     000H
PORTB   .EQ     001H
PORTC   .EQ     002H
CONTROL .EQ     003H

SDIG1   .EQ     0C3H
SDIG2   .EQ     0C2H
SDIG3   .EQ     0C1H
SDIG4   .EQ     0C0H
SDIG5   .EQ     0E3H
SDIG6   .EQ     0E2H
SDIG7   .EQ     0E1H
SDIG8   .EQ     0E0H
;
;-----------------------------------

;-----------------------------------
;
        JMP     START
;
;-----------------------------------
;
;
; SUBROUTINES ETC.
;
; TO ADDRESS REMOTE DISPLAYS PLACE 4 DIGIT WORD IN D+E+H+L
;
DISPLAY MOV     A,D
        OUT     PORTA
        MVI     A,01DH
        OUT     PORTB
        MVI     A,019H
        OUT     PORTB
        MVI     A,01DH
        OUT     PORTB
        MVI     A,005H
        OUT     PORTB
;
        MOV     A,E
        OUT     PORTA
        MVI     A,00DH
        OUT     PORTB
        MVI     A,009H
        OUT     PORTB
        MVI     A,00DH
        OUT     PORTB
        MVI     A,005H
        OUT     PORTB
;
        MOV     A,H
        OUT     PORTA
        MVI     A,015H
        OUT     PORTB
        MVI     A,011H
        OUT     PORTB
        MVI     A,015H
        OUT     PORTB
        MVI     A,005H
        OUT     PORTB
;
        MOV     A,L
        OUT     PORTA
        MVI     A,001H
        OUT     PORTB
        MVI     A,005H
        OUT     PORTB
        RET
;
;------------------------------------
;
START   LXI     SP,$7FF0        STACK SET
        MVI     A,' '           A=20H
        OUT     SDIG1           CLEAR SITCOM DISPLAY
        OUT     SDIG2
        OUT     SDIG3
        OUT     SDIG4
        OUT     SDIG5
        OUT     SDIG6
        OUT     SDIG7
        OUT     SDIG8
        MVI     A,089H          A=89H
        OUT     CONTROL         SENT INIT TO 8255
        MVI     A,000H          A=00H (BUS LINES NOW ALL TO ZERO)
        OUT     PORTA           SEND TO 8255 'DATA BUS' LINES
        MVI     A,005H          A=05H
        OUT     PORTB           DEFAULT SELECT LINES 8255
;
;-------------------------------------
;
        IN      PORTC           READ IN SWITCHES
        CMA                     COMPLIMENT ACCUMULATOR
        ANI     003H            AND WITH 03H
        CPI     001H            COMPARE WITH 01
        JZ      TEST            BLUE BUTTON DOWN RUN TEST
        CPI     002H            COMPARE WITH 02
        JZ      TEST1           GREY BUTTON DOWN RUN TEST1
        JMP     MAIN            JUMP TO MAIN PROGRAM
;
;-------------------------------------
;
TEST1   MVI     A,064H  HALF SCALE DEFLECTION FOR METER
        OUT     PORTA   TO 8255 DATA\BUS
        MVI     A,004H  WRITE D TO A
        OUT     PORTB
        MVI     A,005H
        OUT     PORTB
        JMP     TESTWD
;
;-------------------------------------
;
TEST    MVI     A,0C8H  FULL SCALE DEFLECTION FOR METER
        OUT     PORTA   TO 8255 DATA\BUS
        MVI     A,004H  WRITE D TO A
        OUT     PORTB
        MVI     A,005H
        OUT     PORTB
TESTWD  MVI     A,'T'   LOAD WORD 'TEST' INTO DE+HL
        MOV     D,A
        MVI     A,'E'
        MOV     E,A
        MVI     A,'S'
        MOV     H,A
        MVI     A,'T'
        MOV     L,A
        CALL    DISPLAY  RUN DISPLAY ROUTINE FOR BOARD DL1414

        MVI     A,005H   RESTORE DEFAULT SELECT LINES
        OUT     PORTB
TESTRD  IN      PORTC   READ IN SWITCHES
        ANI     004H    AND WITH 04 (CHECK STATUS OF IR INPUT)
        CPI     004H    IS IT AN 04?
        JZ      LEDON
        MVI     A,005H  DEFAULTS
        OUT     PORTB   SEND TO PORT B
        JMP     TESTRD
LEDON   MVI     A,025H  DEFAULTS PLUS LED ON
        OUT     PORTB   SEND TO PORT B
        JMP     TESTRD
;
;
; END OF TEST ROUTINES
;
;-----------------------------------------------
;
; START OF MAIN SHUTTER TIMER PROGRAMME
;
;-----------------------------------------------
;
MAIN    MVI     A,'S'   Output message "SEL?"
        MOV     D,A
        MVI     A,'E'
        MOV     E,A
        MVI     A,'L'
        MOV     H,A
        MVI     A,"?"
        MOV     L,A
        CALL    DISPLAY
;
BEAMYN  IN      PORTC   READ IN SWS TO CHECK THAT IR BEAM BROKEN
        ANI     004H    AND WITH 04 CHECK STATUS OF IR INPUT
        CPI     004H    IS IT AN O4?
        JNZ     BROKEN  BEAM IS BROKEN SO CAMERA IS IN PLACE
;
;                       BEAM VISIBLE ERROR CAMERA NOT IN PLACE
        MVI     A,' '   SET UP TO DISPLAY THE MSG "ERR"
        MOV     D,A
        MVI     A,'E'
        MOV     E,A
        MVI     A,'R'
        MOV     H,A
        MVI     A,'R'
        MOV     L,A
        CALL    DISPLAY
        JMP     BEAMYN
;
BROKEN  NOP             IR BEAM IS BROKEN WAIT TO MEASURE TIME
;
;        ROUTINE TO LOOK AT BUTTONS AND SELECT TIME
;
SELECT  IN      002H    READ IN SWITCHES FOR CHOSEN SHUTTER SPEED
        CMA
        ANI     003H
        CPI     001H    IS IT BLUE FOR 1/30 SECOND?
        JZ      THIRTY
        CPI     002H    IS IT GREY FOR 1/15 SECOND?
        JZ      FIFT
        JMP     SELECT  RETEST
;
FIFT    MVI     A,'1'   TIMING = 1/15 DISP VALUES
        MOV     D,A
        MVI     A,'/'
        MOV     E,A
        MVI     A,'1'
        MOV     H,A
        MVI     A,'5'
        MOV     L,A
        CALL    DISPLAY SEND 1/15 TO DISPLAY
        MVI     D,0A5H
        MVI     H,0A5H
        MVI     B,000H
        JMP     WAITIN
;
;
THIRTY  MVI     A,'1'   TIMING = 1/30 SEC SET UP DISP AND TIMING VALS
        MOV     D,A
        MVI     A,'/'
        MOV     E,A
        MVI     A,'3'
        MOV     H,A
        MVI     A,'0'
        MOV     L,A
        CALL    DISPLAY SEND 1/30 TO DISPLAY
        MVI     D,065H  SET D TO 1/30 TIMING VALUE
        MVI     H,065H  SET H TO 1/30 TIMING VALUE
        MVI     B,000H  SET B COUNT TO 00
;
WAITIN  IN      PORTC   WAITING FOR SHUTTER TO OPEN
        ANI     004H
        CPI     004H
        JZ      OPEN    JUMP TO OPEN AS SOON AS SHUTTER OPENS
        MVI     A,005H  RELOAD DEFAULTS
        OUT     PORTB
        JMP     WAITIN  TO RETEST IR BEAM
;
OPEN    MVI     A,005H  RELOAD DEFAULTS
        OUT     PORTB
        IN      PORTC
        ANI     004H
        CPI     004H
        JNZ     CLOSED  IR BEAM TESTED AND SHUTTER NOW CLOSED
;
;               SHUTTER STILL OPEN, SO WORK OUT TIMING SO FAR
;
        MOV     H,D     LOAD TIMING VALUE FROM D INTO H
DECH    DCR     H       DECREMENT H AND LOOP UNTIL ZERO
        JNZ     DECH
;                       TIMING VALUE IN D REDUCED TO ZERO
        INR     B       INCREMENT D TO A METER VALUE BY ONE
        MOV     A,B
        CPI     0C8H    COMPARE VALUE FROM B WITH C8h OR 200
        JZ      LONG    JUMP IF ZERO MATCH TO LONG (TOO LONG ERROR)
        JMP     OPEN
;
LONG    MVI     A,'L'   TIMING PERIOD WAS TOO LONG HALT PROGRAM
        MOV     D,A
        MVI     A,'O'
        MOV     E,A
        MVI     A,'N'
        MOV     H,A
        MVI     A,'G'
        MOV     L,A
        CALL    DISPLAY
        MVI     A,005H
        OUT     PORTB
ELONG   JMP     ELONG
;
CLOSED  MVI     A,005H
        OUT     PORTB
        MOV     A,B     LOAD METER VALUE FROM L INTO A
        OUT     PORTA   WRITE TO 8255 "DATA BUS"
        MVI     A,004H  WRITE TO THE D TO A AND THEREBY TO METER
        OUT     001H
FINISH  JMP     FINISH


